@@ -1,4 +1,4 @@
-/* Copyright 2015--2017 The Tor Project
+/* Copyright 2015--2018 The Tor Project
  * See LICENSE for licensing information */
 
 package org.torproject.onionoo.docs;
@@ -26,7 +26,8 @@ public class SummaryDocumentTest {
         new String[] { "001C13B3A55A71B977CA65EC85539D79C653A3FC",
             "0025C136C1F3A9EEFE2AE3F918F03BFA21B5070B" })),
         new TreeSet<>(Arrays.asList(
-        new String[] { "001C13B3A55A71B977CA65EC85539D79C653A3FC" })), null);
+        new String[] { "001C13B3A55A71B977CA65EC85539D79C653A3FC" })), null,
+        null, true);
   }
 
   @Test()
