@@ -13,7 +13,11 @@ import org.torproject.onionoo.docs.DocumentStoreFactory;
 import org.torproject.onionoo.docs.DummyDocumentStore;
 import org.torproject.onionoo.docs.UpdateStatus;
 
-import com.google.gson.Gson;
+import com.fasterxml.jackson.annotation.JsonAutoDetect;
+import com.fasterxml.jackson.annotation.JsonInclude;
+import com.fasterxml.jackson.annotation.PropertyAccessor;
+import com.fasterxml.jackson.databind.ObjectMapper;
+import com.fasterxml.jackson.databind.PropertyNamingStrategy;
 
 import org.junit.Before;
 import org.junit.Test;
@@ -36,6 +40,12 @@ import java.util.TreeSet;
  * which tests servlet specifics. */
 public class ResourceServletTest {
 
+  private static ObjectMapper objectMapper = new ObjectMapper()
+      .setPropertyNamingStrategy(PropertyNamingStrategy.SNAKE_CASE)
+      .setSerializationInclusion(JsonInclude.Include.NON_EMPTY)
+      .setVisibility(PropertyAccessor.ALL, JsonAutoDetect.Visibility.NONE)
+      .setVisibility(PropertyAccessor.FIELD, JsonAutoDetect.Visibility.ANY);
+
   private SortedMap<String, org.torproject.onionoo.docs.SummaryDocument> relays;
   private SortedMap<String, org.torproject.onionoo.docs.SummaryDocument>
       bridges;
@@ -263,11 +273,10 @@ public class ResourceServletTest {
     rs.doGet(this.request, this.response, TEST_TIME);
   }
 
-  private void parseResponse() {
+  private void parseResponse() throws IOException {
     this.responseString = this.response.getWrittenContent();
     if (this.responseString != null) {
-      Gson gson = new Gson();
-      this.summaryDocument = gson.fromJson(this.responseString,
+      this.summaryDocument = objectMapper.readValue(this.responseString,
           SummaryDocument.class);
     }
   }
@@ -344,6 +353,9 @@ public class ResourceServletTest {
 
   @SuppressWarnings("MemberName")
   private static class SummaryDocument {
+    private String version;
+    private String next_major_version_scheduled;
+    private String build_revision;
     private String relays_published;
     private int relays_skipped;
     private int relays_truncated;
@@ -1419,7 +1431,7 @@ public class ResourceServletTest {
         "/summary?order=" + OrderParameterValues.FIRST_SEEN_ASC + ","
         + OrderParameterValues.CONSENSUS_WEIGHT_ASC, 3,
         new String[] { "TimMayTribute", "Ferrari458", "TorkaZ" }, 3,
-        new String[] { "gummy", null, "ec2bridgercc7f31fe" });
+        new String[] { "gummy", "Unnamed", "ec2bridgercc7f31fe" });
   }
 
   @Test(timeout = 100)
@@ -1428,7 +1440,7 @@ public class ResourceServletTest {
         + OrderParameterValues.FIRST_SEEN_DES + ","
         + OrderParameterValues.CONSENSUS_WEIGHT_ASC, 3,
         new String[] { "TorkaZ", "TimMayTribute", "Ferrari458" }, 3,
-        new String[] { "ec2bridgercc7f31fe", null, "gummy" });
+        new String[] { "ec2bridgercc7f31fe", "Unnamed", "gummy" });
   }
 
   @Test(timeout = 100)
